crowdastro
==========

This project aims to develop a machine learned method for
cross-identifying radio objects and their host galaxies, using
crowdsourced labels from the `Radio Galaxy
Zoo <http://radio.galaxyzoo.org>`__.

|Travis-CI| |Documentation Status| |DOI|

For setup details, see the documentation on `Read the
Docs <http://crowdastro.readthedocs.io/en/latest/>`__.

For a brief description of each notebook, see the documentation
`here <docs/notebooks.md>`__.

The cross-identification dataset is available `on
Zenodo <http://dx.doi.org/10.5281/zenodo.58316>`__.

.. |Travis-CI| image:: https://travis-ci.org/chengsoonong/crowdastro.svg?branch=master
   :target: https://travis-ci.org/chengsoonong/crowdastro
.. |Documentation Status| image:: https://readthedocs.org/projects/crowdastro/badge/?version=latest
   :target: http://crowdastro.readthedocs.io/en/latest/?badge=latest
.. |DOI| image:: https://zenodo.org/badge/doi/10.5281/zenodo.58316.svg
   :target: http://dx.doi.org/10.5281/zenodo.58316
